@@ -3,8 +3,10 @@ setClassUnion("extlogical",c("logical","NULL"))
 setClassUnion("extnumeric",c("numeric","NULL"))
 setClassUnion("extcharacter",c("character","NULL"))
 setClassUnion("extinteger",c("integer","NULL"))
+setClassUnion("exttable",c("table","NULL"))
+
 setClass("IData",slots=c(MidP="data.frame",LogR="data.frame",ObsNames="character",VarNames="character",
-  NObs="numeric",NIVar="numeric",NbMicroUnits="integer"))
+  NObs="numeric",NIVar="numeric",NbMicroUnits="integer",Transform="character"))
 setClass("IdtE",slots=c(ModelNames="character",ModelType="character",ModelConfig="numeric",NIVar="numeric",SelCrit="character",
   logLiks="numeric",BICs="numeric",AICs="numeric",BestModel="numeric",SngD="logical"),contains="VIRTUAL")
 setClass("IdtMclust",slots=c(call="call",data="IData",NObs="numeric",NIVar="numeric",SelCrit="character",Hmcdt="logical",
@@ -88,7 +90,8 @@ setClass("IdtOutl",slots=c(outliers="extinteger", MD2="numeric",eta="numeric",Re
 #  multiCmpCor="character",NObs="numeric",p="numeric",h="numeric",boolRewind="extlogical"))
   multiCmpCor="character",NObs="numeric",p="numeric",h="numeric",boolRewind="extlogical",trshld="numeric"))
 
-setClass("summaryIData",slots=c(MidPsumar="table", Rngsumar="table",LogRsumar="table"))
+#setClass("summaryIData",slots=c(MidPsumar="table", Rngsumar="table",LogRsumar="table",LogitMidPsumar="table",LogitRsumar="table",Transform="character"))
+setClass("summaryIData",slots=c(MidPsumar="table", Rngsumar="table",LogRsumar="exttable",LogitMidPsumar="exttable",LogitRsumar="exttable",Transform="character"))
 
 
 setGeneric("nrow")
