@@ -2,9 +2,25 @@ setMethod("summary",
   signature(object = "IData"),
   function (object) 
   {
-    Rngsumar <- summary(exp(object@LogR))
+    if (object@Transform=="RngLog") {
+      MidPsumar <- summary(object@MidP)
+      Rngsumar <- summary(exp(object@LogR))
+      LogRsumar <- summary(object@LogR)
+      LogitMidPsumar <- NULL
+      LogitRsumar <- NULL
+    } else if (object@Transform=="AllLogit") {
+      MidPsumar=summary(invlogit(object@MidP))
+      Rngsumar <- summary(invlogit(object@LogR))
+      LogRsumar <- NULL
+      LogitMidPsumar <- summary(object@MidP)
+      LogitRsumar <- summary(object@LogR)
+      dimnames(LogitMidPsumar)[[2]] <- paste(object@VarNames,".LogitMidP",sep="")
+      dimnames(LogitRsumar)[[2]] <- paste(object@VarNames,".LogitRange",sep="")
+    }  
     dimnames(Rngsumar)[[2]] <- paste(object@VarNames,".Range",sep="")
-    show(new("summaryIData",MidPsumar=summary(object@MidP),Rngsumar=Rngsumar,LogRsumar=summary(object@LogR)))
+    show(new("summaryIData",
+             MidPsumar=MidPsumar,Rngsumar=Rngsumar,LogRsumar=LogRsumar,LogitMidPsumar=LogitMidPsumar,LogitRsumar=LogitRsumar,Transform=object@Transform)
+         )
   }
 )
 
@@ -21,9 +37,16 @@ setMethod("show",
       cat("\n")
     }
 
-    HalfRange <- exp(object@LogR)/2
-    LB <- object@MidP - HalfRange
-    UB <- object@MidP + HalfRange
+    if (object@Transform=="RngLog") {
+      HalfRange <- exp(object@LogR)/2
+      LB <- object@MidP - HalfRange
+      UB <- object@MidP + HalfRange
+    } else if (object@Transform=="AllLogit") {
+      HalfRange <- invlogit(object@LogR)/2
+      MidPoint <- invlogit(object@MidP)
+      LB <- MidPoint - HalfRange
+      UB <- MidPoint + HalfRange
+    } 
     lobsname <- max(nchar(object@ObsNames))
     flength <- max(nchar(object@VarNames),nchar(format(LB[1,1],width=8,digits=5))+nchar(format(UB[1,1],width=8,digits=5))) + 6 
     for (j in 1:object@NIVar) {
@@ -119,13 +142,25 @@ setMethod("plot",
       dotarguments$ylab <- y@VarNames
     }
 
+    if (x@Transform=="RngLog") {
+      MidPx <- x@MidP[,1]
+      HlfRngx <- exp(x@LogR[,1])/2
+    } else if (x@Transform=="AllLogit") {
+      MidPx <- invlogit(x@MidP[,1])
+      HlfRngx <- invlogit(x@LogR[,1])/2
+    }  
+    if (y@Transform=="RngLog") {
+      MidPy <- y@MidP[,1]
+      HlfRngy <- exp(y@LogR[,1])/2
+    } else if (y@Transform=="AllLogit") {
+      MidPy <- invlogit(y@MidP[,1])
+      HlfRngy <- invlogit(y@LogR[,1])/2
+    }  
 
-    HlfRngx <- exp(x@LogR[,1])/2
-    Lbx <- x@MidP[,1] - HlfRngx
-    Ubx <- x@MidP[,1] + HlfRngx
-    HlfRngy <- exp(y@LogR[,1])/2
-    Lby <- y@MidP[,1] - HlfRngy
-    Uby <- y@MidP[,1] + HlfRngy
+    Lbx <- MidPx - HlfRngx
+    Ubx <- MidPx + HlfRngx
+    Lby <- MidPy - HlfRngy
+    Uby <- MidPy + HlfRngy
 
     if (is.null(dotarguments$xlim)) {
       minvx <- min(Lbx)
@@ -143,10 +178,9 @@ setMethod("plot",
     }
 
     if (type=="crosses") {
-      do.call("segments",c(list(x0=Lbx,y0=y@MidP[,1],x1=Ubx,y1=y@MidP[,1]),dotarguments))
-      do.call("segments",c(list(x0=x@MidP[,1],y0=Lby,x1=x@MidP[,1],y1=Uby),dotarguments))
+      do.call("segments",c(list(x0=Lbx,y0=MidPy,x1=Ubx,y1=MidPy),dotarguments))
+      do.call("segments",c(list(x0=MidPx,y0=Lby,x1=MidPx,y1=Uby),dotarguments))
     } else if (type=="rectangles") {
-#      for (i in 1:x@NObs) rect(Lbx[i],Lby[i],Ubx[i],Uby[i],lty=1)
         for (i in 1:x@NObs) do.call("rect",c(Lbx[i],Lby[i],Ubx[i],Uby[i], dotarguments))
     }
   }
@@ -223,15 +257,22 @@ setMethod("show",
   {
     cat("Mid-Points summary:\n") ; print(object@MidPsumar)
     cat("Ranges summary:\n") ; print(object@Rngsumar)
-    cat("Log-Ranges summary:\n") ; print(object@LogRsumar)
+    if (object@Transform=="RngLog") {
+      cat("Log-Ranges summary:\n") ; print(object@LogRsumar)
+    } else if (object@Transform=="AllLogit") {
+      cat("Logit-MidPoints summary:\n") ; print(object@LogitMidPsumar)
+      cat("Logit-Ranges summary:\n") ; print(object@LogitRsumar)
+    }  
     invisible(object)
   }
 )
 
 setMethod("print", signature(x="summaryIData"), function(x,...) invisible(x) )
 
-IData <- function(Data,
-#  Seq=c("LbUb_VarbyVar","MidPLogR_VarbyVar","AllLb_AllUb","AllMidP_AllLogR"),VarNames=NULL,ObsNames=row.names(Data))
+logit <- function(x) log(x/(1-x))
+invlogit <- function(x) { ex <- exp(x) ; ex/(1+ex) }
+
+IData <- function(Data, trnsf = c("RngLog","AllLogit"), 
   Seq=c("LbUb_VarbyVar","MidPLogR_VarbyVar","AllLb_AllUb","AllMidP_AllLogR"),VarNames=NULL,ObsNames=row.names(Data),NbMicroUnits=integer(0))
 {
   if ( !is.data.frame(Data) && !is.matrix(Data) ) stop("First argument of IData must be a data frame or a matrix\n")
@@ -240,6 +281,7 @@ IData <- function(Data,
     NbMicroUnits <- as.integer(NbMicroUnits)
     names(NbMicroUnits) <- unitnames
   }  
+  trnsf <- match.arg(trnsf)
   
   p <- ncol(Data)  # Total number of Interval variable bounds
   q <- p/2	 # Number of Interval variables
@@ -249,8 +291,14 @@ IData <- function(Data,
   {
     if (Seq == "LbUb_VarbyVar") { Lbnd <- Data[,2*(0:(q-1))+1] ; Ubnd <- Data[,2*(1:q)] }
     if (Seq == "AllLb_AllUb")   { Lbnd <- Data[,1:q] ; Ubnd <- Data[,(q+1):p] }
-    MidP <- (Lbnd+Ubnd)/2
-    LogR <- log(Ubnd-Lbnd)
+    if (trnsf=="RngLog") {
+      MidP <- (Lbnd+Ubnd)/2
+      LogR <- log(Ubnd-Lbnd)
+    }  
+    else if (trnsf=="AllLogit") {
+      MidP <- logit((Lbnd+Ubnd)/2)
+      LogR <- logit(Ubnd-Lbnd)
+    }  
     if (any(is.na(LogR))) stop("Invalid data")
   } else {
     if (Seq == "MidPLogR_VarbyVar") { MidP <- Data[,2*(0:(q-1))+1] ; LogR <- Data[,2*(1:q)] }
@@ -259,13 +307,17 @@ IData <- function(Data,
   if (is.null(VarNames)) VarNames <- paste("I",1:q,sep="")
   if (!is.data.frame(MidP)) MidP <- as.data.frame(MidP)
   if (!is.data.frame(LogR)) LogR <- as.data.frame(LogR)
-  names(MidP) <- paste(VarNames,".MidP",sep="")
-  names(LogR) <- paste(VarNames,".LogR",sep="")
+  if (trnsf=="RngLog") {
+    names(MidP) <- paste(VarNames,".MidP",sep="")
+    names(LogR) <- paste(VarNames,".LogR",sep="")
+  }  else if (trnsf=="AllLogit") {
+    names(MidP) <- paste(VarNames,".LogitMidP",sep="")
+    names(LogR) <- paste(VarNames,".LogitR",sep="")
+  }  
   if (is.null(ObsNames)) ObsNames <- as.character(1:nrow(MidP))
   rownames(MidP) <- rownames(LogR) <- ObsNames
 
-#  new("IData",MidP=MidP,LogR=LogR,ObsNames=ObsNames,VarNames=VarNames,NObs=nrow(MidP),NIVar=q,NbMicroUnits=integer(0))
-  new("IData",MidP=MidP,LogR=LogR,ObsNames=ObsNames,VarNames=VarNames,NObs=nrow(MidP),NIVar=q,NbMicroUnits=NbMicroUnits)
+  new("IData",MidP=MidP,LogR=LogR,ObsNames=ObsNames,VarNames=VarNames,NObs=nrow(MidP),NIVar=q,NbMicroUnits=NbMicroUnits,Transform=trnsf)
 }
 
 # Standard operators for IData objects
@@ -280,7 +332,9 @@ setMethod("[",
     if (missing(j)) j <- 1:ncol(x)  
     if (is.character(i)) i <- sapply(i,function(ri) which(ri==x@ObsNames))
     if (is.character(j)) j <- sapply(j,function(ci) which(ci==x@VarNames))
-    IData(cbind(x@MidP[i,j,drop=FALSE],x@LogR[i,j,drop=FALSE]),
+    if (length(x@NbMicroUnits) > 0) NbMicUn <- x@NbMicroUnits[i]  
+    else NbMicUn <- integer(0)
+    IData(cbind(x@MidP[i,j,drop=FALSE],x@LogR[i,j,drop=FALSE]),NbMicroUnits=NbMicUn,trnsf=x@Transform,
       Seq="AllMidP_AllLogR",VarNames=x@VarNames[j],ObsNames=x@ObsNames[i])
   }
 )
@@ -296,6 +350,7 @@ setMethod("[<-",
     if (is.character(j)) j <- sapply(j,function(ci) which(ci==x@VarNames))
     x@MidP[i,j] <- value@MidP
     x@LogR[i,j] <- value@LogR
+    if (length(x@NbMicroUnits) > 0) x@NbMicroUnits[i] <- value@NbMicroUnits
     x
   }
 )
@@ -312,6 +367,9 @@ setMethod("==",
       stop("Trying to compare an IData object with an object of a diferent type\n")
     if ( e1@NObs != e2@NObs || e1@NIVar != e2@NIVar )
       stop("== only defined for equally-sized IData objects\n")
+    if ( length(e1@NbMicroUnits)!=length(e2@NbMicroUnits) ) return(FALSE)
+    if ( length(e1@NbMicroUnits)>0 && any(e1@NbMicroUnits!=e2@NbMicroUnits) ) return(FALSE)
+    if (e1@Transform!=e2@Transform) return(FALSE)
     TmpArray <- array(dim=c(e1@NObs,e1@NIVar,2,2))
     for (j in 1:e1@NIVar)  {
       TmpArray[,j,,1] <- cbind(e1@MidP[,j],e1@LogR[,j])
@@ -342,16 +400,16 @@ setMethod(rbind,
     x <- eval(dotarguments[[1]])
     for (nextarg in 2:length(dotarguments)) {
       y <- eval(dotarguments[[nextarg]])
-#      if (class(y)[1]!="IData") stop("Argument y is not an object of class IData\n")
       if (!inherits(y,"IData")) stop("Argument y is not an object of class IData\n")
       if (x@NIVar != y@NIVar) stop("Arguments x and y have a different number of interval-valued variables\n")
+      if (x@Transform != y@Transform) stop("Arguments x and y are based on different data transformations\n")
       dataDF <- rbind(cbind(x@MidP,x@LogR),cbind(y@MidP,y@LogR))
       if (x@NIVar==1) {
         ONames <- c(x@ObsNames,y@ObsNames)
       } else {
         ONames <- rownames(dataDF)
       }
-      x <- IData(dataDF,Seq="AllMidP_AllLogR",ObsNames=ONames,VarNames=x@VarNames)
+      x <- IData(dataDF,Seq="AllMidP_AllLogR",ObsNames=ONames,VarNames=x@VarNames,NbMicroUnits=c(x@NbMicroUnits,y@NbMicroUnits),trnsf=x@Transform)
     }
     x
   }
@@ -365,9 +423,13 @@ setMethod(cbind,
     x <- eval(dotarguments[[1]])
     for (nextarg in 2:length(dotarguments)) {
       y <- eval(dotarguments[[nextarg]])
-#      if (class(y)[1]!="IData") stop("Argument y is not an object of class IData\n")
       if (!inherits(y,"IData"))  stop("Argument y is not an object of class IData\n")
       if (x@NObs != y@NObs) stop("Arguments x and y have a different number of rows\n")
+      if (length(x@NbMicroUnits)>0) {
+        if ( length(y@NbMicroUnits)>0 && any(x@NbMicroUnits!=y@NbMicroUnits) ) stop("Incompatible NbMicroUnits vectores for arguments x and y\n")
+        if (x@Transform != y@Transform) stop("Arguments x and y are based on different data transformations\n")
+        NbMicUn <- x@NbMicroUnits 
+      } else NbMicUn <- y@NbMicroUnits 
       dataDF <- cbind(x@MidP,y@MidP,x@LogR,y@LogR)
       if (x@NIVar==1 && y@NIVar==1) rownames(dataDF) <- x@ObsNames
       VNames <- c(x@VarNames,y@VarNames)
@@ -384,7 +446,7 @@ setMethod(cbind,
       #   VNames <- c(VNames,newIDtObj@VarNames)
       #   curnIvar <- curnIvar + newIDtObj@NIVar
       # }
-      x <- IData(dataDF,Seq="AllMidP_AllLogR",VarNames=VNames)
+      x <- IData(dataDF,Seq="AllMidP_AllLogR",VarNames=VNames,NbMicroUnits=NbMicUn,trnsf=x@Transform)
     }
   x
   }
