@@ -40,7 +40,7 @@ template<class MT>
 void RprintM_rctb(const int m,const int n,const MT& M)
 {
   for (int r=0;r<m;r++) {
-    for (int c=0;c<n;c++) Rprintf("%f ",M[r,c]);
+    for (int c=0;c<n;c++) Rprintf("%f ",M[r][c]);
     Rprintf("\n");
   }
   Rprintf("\n");
